import os

from zcmds_win32.unix_tool_path import unix_tool_exec

CMDNAME = "bash.exe"

GIT_BIN = r"C:\Program Files\Git\usr\bin"

ENV = os.environ.copy()
OS_PATH_SEP = os.pathsep
ENV["PATH"] = f"{GIT_BIN}{OS_PATH_SEP}{ENV['PATH']}"
os.environ.update(ENV)


def main() -> int:
    return unix_tool_exec(
        CMDNAME,
    )



"""
Fixes the VMMem issue on Windows 10.
"""

import sys

from sudo_win32.elevated_exec import elevated_exec  # type: ignore


def main() -> int:
    """Main entry point."""
    return elevated_exec("taskkill /F /im wslservice.exe")


if __name__ == "__main__":
    sys.exit(main())



import os
import unittest
from zcmds_win32.unix_tool_path import install
from zcmds_win32.settings import SRC_ROOT

LS_GIT_BIN_PATH = SRC_ROOT / "git-bash-bin" / "ls.exe"


class GitBinInstallTester(unittest.TestCase):
    def test_install(self) -> None:
        """Tests that the download works."""
        install()
        self.assertTrue(os.path.exists(LS_GIT_BIN_PATH), f"Could not find {LS_GIT_BIN_PATH}")


if __name__ == "__main__":
    unittest.main()



import os
import shutil
import sys
from dataclasses import dataclass
from typing import Optional

from zcmds_win32._exec import os_exec


@dataclass
class Program:
    path: str
    args: list[str]


def get_sublime() -> Optional[Program]:
    """Attempts to find the Sublime Text executable."""
    path = shutil.which("subl") or shutil.which("sublime_text")
    args = ["-n"]
    if path:
        return Program(path, args)
    for i in ["", "2", "3", "4"]:
        path = f"C:\\Program Files\\Sublime Text{i}\\sublime_text.exe"
        if os.path.exists(path):
            return Program(path, args)
    return None


def get_textpad() -> Optional[Program]:
    path = shutil.which("textpad")
    if path:
        return Program(path, [])
    for i in ["", "2", "3", "4", "5", "6", "7", "8"]:
        path = f"C:\\Program Files\\TextPad {i}\\TextPad.exe"
        if os.path.exists(path):
            return Program(path, [])
    return None


TEXT_EDITOR = get_sublime() or get_textpad()

TEXT_EXTENSIONS = [
    ".c",
    ".cpp",
    ".cxx",
    ".cc",
    ".c++",
    ".h",
    ".hpp",
    ".hxx",
    ".hh",
    ".h++",
    ".py",
    ".kt",
    ".java",
    ".js",
    ".ts",
    ".html",
    ".css",
    ".scss",
    ".sass",
    ".less",
    ".json",
    ".xml",
    ".yml",
    ".yaml",
    ".md",
    ".txt",
    ".bat",
    ".cmd",
    ".sh",
    ".ps1",
    ".pub",
    ".pem",
    ".key",
    ".crt",
    ".cer",
    ".pfx",
    ".toml",
]

IMAGE_EXTENSIONS = [
    ".png",
    ".jpg",
    ".jpeg",
    ".gif",
    ".bmp",
    ".ico",
    ".webp",
    ".svg",
]


def handle_file(file: str) -> tuple[bool, int]:
    """Attempts to handle the file with a specific program."""
    ext = os.path.splitext(file)[1]
    file_uses_text_encoding = False
    with open(file, "rb") as f:
        try:
            f.read().decode("utf-8")
            file_uses_text_encoding = True
        except UnicodeDecodeError:
            pass
    if ext.lower() in TEXT_EXTENSIONS or ext.lower() == "" and file_uses_text_encoding:
        if TEXT_EDITOR:
            # empty quotes is for title.
            args_statement = " ".join(TEXT_EDITOR.args)
            cmd = f'start "" "{TEXT_EDITOR.path}" {args_statement} "{file}"'
            rtn = os.system(cmd)
            return (True, rtn)
    if ext.lower() in IMAGE_EXTENSIONS:
        cmd = f'explorer "{file}"'
        rtn = os.system(cmd)
        return (True, rtn)
    return (False, 0)


def git_bash_path_to_windows(path: str) -> str:
    if path.startswith("/"):
        drive = path[1].upper()
        return drive + ":" + path[2:].replace("/", "\\")
    else:
        return path


def main() -> int:
    cmd = "explorer"
    if len(sys.argv) == 1:
        cmd += " ."
        return os.system(cmd)
    for i, _ in enumerate(sys.argv):
        if i < 1:
            continue
        arg = git_bash_path_to_windows(sys.argv[i])
        arg = arg.replace("\\\\", "\\")
        sys.argv[i] = arg
        if os.path.isfile(arg):
            handled, ret = handle_file(arg)
            if handled:
                return ret
    arg = sys.argv[1]
    if arg == ".":
        return os.system("explorer .")
    return os_exec(cmd)


def unit_test() -> None:
    """Unit test for this module."""
    # target = r"C:\Users\niteris\dev\StatsDashPublic\www\src\assets\preview_image.webp"
    sys.argv.append(".")
    main()


if __name__ == "__main__":
    unit_test()



import os
import shutil
from tempfile import TemporaryDirectory
from typing import Optional

from download import download  # type: ignore

HERE = os.path.abspath(os.path.dirname(__file__))

DOWNLOAD_DIR = os.path.join(HERE, "downloads")


def install(tool_url: str, dst_dir: str) -> None:
    """Installs the Unix tools."""
    with TemporaryDirectory() as tmpdir:
        download(tool_url, tmpdir, replace=True, kind="zip")
        os.makedirs(dst_dir, exist_ok=True)
        shutil.rmtree(dst_dir, ignore_errors=True)
        shutil.copytree(tmpdir, dst_dir)


def get_or_fetch_tool(toolname: str, tooldir: str, url: str) -> Optional[str]:
    """Attempts to find the given Unix tool."""
    path = shutil.which(toolname)
    if path and os.path.basename(os.path.dirname(path)).lower() != "scripts":
        return path
    # add .exe to the name if it's not there
    if not toolname.lower().endswith(".exe"):
        toolname += ".exe"
    expected_path = os.path.join(tooldir, toolname)
    if os.path.exists(expected_path):
        return os.path.join(tooldir, toolname)
    if not os.path.exists(expected_path):
        install(url, tooldir)
    return os.path.join(tooldir, toolname)


def main() -> int:
    toolname = "dig.exe"
    tooldir = os.path.join(HERE, "downloads", "dig_dl.9.0.5")
    url = "https://github.com/zackees/zcmds_win32/raw/main/assets/dig-for-windows-9.9.5-W1.zip"
    path = get_or_fetch_tool(toolname, tooldir, url)
    print(path)
    assert path == os.path.join(tooldir, toolname)
    print("OK")
    return 0


if __name__ == "__main__":
    main()



import os

from zcmds_win32._exec import os_exec
from zcmds_win32.install_tool import DOWNLOAD_DIR, get_or_fetch_tool

TOOL = "dig.exe"
# DIR = os.path.join(HERE, "downloads", "dig_dl.9.0.5")
DEST_DIR = os.path.join(DOWNLOAD_DIR, "dig_dl.9.0.5")
URL = "https://github.com/zackees/zcmds_win32/raw/main/assets/dig-for-windows-9.9.5-W1.zip"


def main() -> int:
    path = get_or_fetch_tool(toolname=TOOL, tooldir=DEST_DIR, url=URL)
    assert path
    # os.system(f"{path} +short myip.opendns.com @resolver1.opendns.com")
    return os_exec(cmd=path, inherit_params=True, cwd=None)


if __name__ == "__main__":
    main()



import unittest


class MainTester(unittest.TestCase):
    def test_imports(self) -> None:
        """Tests the imports."""
        import zcmds_win32.cmds.fixvmmem
        import zcmds_win32.cmds.open
        import zcmds_win32.unix_tool_path
        import zcmds_win32._exec

    def test_ls(self) -> None:
        """Tests the ls command."""
        import zcmds_win32.cmds.ls

        zcmds_win32.cmds.ls.main()


if __name__ == "__main__":
    unittest.main()



import argparse

from zcmds_win32.unix_tool_path import install


def main() -> int:
    """Main entry point."""
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--install",
        action="store_true",
        help="Install the Unix tools",
    )
    args = parser.parse_args()
    if args.install:
        install()
    return 0



import os
import unittest


class DigTester(unittest.TestCase):
    def test_dig_main(self) -> None:
        """Tests the ls command."""
        import zcmds_win32.cmds.dig

        zcmds_win32.cmds.dig.main()

    def test_dig_cmd(self) -> None:
        """Tests the ls command."""

        os.system("dig google.com")


if __name__ == "__main__":
    unittest.main()



"""
Installs and runs the `make` command on Windows.
This one is a little difficult because the binary is located in bin/make.exe
"""

import os
import shutil
from tempfile import TemporaryDirectory
from typing import Optional

from download import download  # type: ignore

from zcmds_win32._exec import os_exec
from zcmds_win32.install_tool import DOWNLOAD_DIR

CMDNAME = "make.exe"
URL = "https://github.com/zackees/zcmds_win32/raw/main/assets/make-3.81-bin.zip"
DEST_DIR = os.path.join(DOWNLOAD_DIR, "make")


HERE = os.path.abspath(os.path.dirname(__file__))

DOWNLOAD_DIR = os.path.join(HERE, "downloads")


def _install(tool_url: str, dst_dir: str) -> None:
    """Installs the Unix tools."""
    with TemporaryDirectory() as tmpdir:
        download(tool_url, tmpdir, replace=True, kind="zip")
        os.makedirs(dst_dir, exist_ok=True)
        shutil.rmtree(dst_dir, ignore_errors=True)
        shutil.copytree(tmpdir, dst_dir)


def _get_or_fetch_tool(tooldir: str, url: str) -> Optional[str]:
    """Attempts to find the given Unix tool."""
    path = shutil.which(CMDNAME)
    if path and os.path.basename(os.path.dirname(path)).lower() != "scripts":
        return path
    # add .exe to the name if it's not there
    expected_path = os.path.join(tooldir, "bin", CMDNAME)
    if os.path.exists(expected_path):
        return expected_path
    if not os.path.exists(expected_path):
        _install(url, tooldir)
    return os.path.join(tooldir, "bin", CMDNAME)


def main() -> int:
    path = _get_or_fetch_tool(tooldir=DEST_DIR, url=URL)
    assert path
    return os_exec(cmd=path, inherit_params=True, cwd=None)


if __name__ == "__main__":
    main()



"""Helper to execute a command."""

import subprocess
import sys
from typing import Optional


def os_exec(
    cmd: str, inherit_params: bool = True, cwd: Optional[str] = None, **kwargs
) -> int:
    cmd_list = [cmd]
    if inherit_params:
        cmd_list += sys.argv[1:]
    rtn = subprocess.call(cmd_list, cwd=cwd, universal_newlines=True, **kwargs)
    return rtn
